#
# spec file for package tuxguitar
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tuxguitar
Version:        1.6.6
Release:        1.1
Summary:        A multitrack tablature editor and player written in Java-SWT
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://github.com/helge17/tuxguitar
Source0:        https://github.com/helge17/tuxguitar/archive/refs/tags/%{version}.tar.gz
Patch11:        0009-no-lv2.patch
Patch12:        0010-no-fluidsynth.patch
Patch20:        0011-default-soundfont.patch
Patch21:        0012-startscript.patch
BuildRequires:  alsa-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  jack-audio-connection-kit-devel
BuildRequires:  libQt5Core-devel
BuildRequires:  libQt5Widgets-devel
BuildRequires:  maven-local
BuildRequires:  update-desktop-files
BuildRequires:  mvn(com.itextpdf:itextpdf)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-dependency-plugin)
BuildRequires:  mvn(org.eclipse.swt:org.eclipse.swt)
Requires:       apache-commons-compress
Requires:       eclipse-swt >= 4.13
Recommends:     snd_sf2
Recommends:     timidity
Recommends:     wqy-zenhei-fonts
Suggests:       fluid-soundfont-gm
%if 0%{?suse_version} >= 1500
BuildRequires:  fluidsynth-devel
BuildRequires:  liblilv-0-devel
%endif
%if 0%{?suse_version} > 1500
BuildRequires:  suil-devel
%endif

%description
TuxGuitar is a guitar tablature editor with player support through midi. It can
display scores and multitrack tabs. Various features TuxGuitar provides include
autoscrolling while playing, note duration management, bend/slide/vibrato/
hammer-on/pull-off effects, support for tuplets, time signature management,
tempo management, gp3/gp4/gp5/gpx import and export.

%prep
%setup -q
find . -name "*.exe" -print -delete
find . -name "*.dll" -print -delete
find . -name "*.sf2" -print -delete
find . -name "*.jar" -print -delete
find . -name "*.so" -print -delete

# In source archive, all modules have an attribute "VERSION" set to "SNAPSHOT"
# this attribute is set during build/delivery
# Refer to application delivery process :
#   https://github.com/helge17/tuxguitar/blob/bd6b29c9539d66b625a625e70bd8718497aa107b/misc/build_tuxguitar_from_source.sh#L148
find . \( -name "*.xml" -or -name "*.gradle"  -or -name "*.properties" -or -name "*.html" -or -name control -or -name Info.plist -or -name CHANGES \) -and -not -path "./website/*" -and -type f -exec sed -i "s/9.99-SNAPSHOT/%{version}/" '{}' \;

# Also set the version in the "Help - About" dialog
sed -i "s/static final String RELEASE_NAME =.*/static final String RELEASE_NAME = (TGApplication.NAME + \" %{version}\");/" desktop/TuxGuitar/src/org/herac/tuxguitar/app/view/dialog/about/TGAboutDialog.java

%if 0%{?suse_version} <= 1500
%patch -P 11 -p1
%endif
%if 0%{?suse_version} < 1500
%patch -P 12 -p1
%endif

%patch -P 20 -p1
%patch -P 21 -p1

%pom_xpath_remove "pom:profile[pom:id[text()='platform-windows']]" desktop/pom.xml
%pom_xpath_remove "pom:profile[pom:id[text()='platform-macos-cocoa']]" desktop/pom.xml
%pom_xpath_remove "pom:profile[pom:id[text()='platform-freebsd']]" desktop/pom.xml
%pom_xpath_set -r pom:org.eclipse.swt.artifactId org.eclipse.swt  desktop/pom.xml
%pom_xpath_set -r pom:org.eclipse.swt.artifactId org.eclipse.swt desktop/build-scripts/%{name}-linux-swt
%pom_xpath_remove "pom:artifactItem[pom:destFileName[text()='swt.jar']]" desktop/build-scripts/%{name}-linux-swt
%pom_remove_dep :org.eclipse.swt.gtk.linux desktop/pom.xml
%pom_remove_dep :org.eclipse.swt.win32.win32 desktop/pom.xml
%pom_remove_dep :org.eclipse.swt.cocoa.macosx desktop/pom.xml

%build
%{mvn_build} -j -f -- \
    -e -f desktop/build-scripts/%{name}-linux-swt/pom.xml \
    -Dproject.build.sourceEncoding=UTF-8 -Dnative-modules=true

%install
%mvn_install

# install jnis we built
mkdir -p %{buildroot}%{_libdir}/%{name}
cp -a desktop/build-scripts/native-modules/*/target/build/lib/*.so %{buildroot}%{_libdir}/%{name}/

# Launch script
mkdir -p %{buildroot}/%{_bindir}
cat desktop/build-scripts/common-resources/common-linux/tuxguitar.sh | sed 's#@LIBDIR@#%{_libdir}#g' > %{buildroot}/%{_bindir}/%{name}

# Fix permissions
chmod 755 %{buildroot}/%{_bindir}/%{name}
chmod 755 %{buildroot}%{_libdir}/%{name}/*.so

# mime types
mkdir -p %{buildroot}/%{_datadir}/mime/packages/
cp -a desktop/build-scripts/common-resources/common-linux/share/mime/packages/tuxguitar.xml %{buildroot}/%{_datadir}/mime/packages/

# data files
mkdir -p %{buildroot}/%{_datadir}/%{name}
cp -a desktop/TuxGuitar/share/* %{buildroot}/%{_datadir}/%{name}
cp -a common/resources/* %{buildroot}/%{_datadir}/%{name}
cp -a misc/tuxguitar.tg %{buildroot}/%{_datadir}/%{name}
cp -a desktop/build-scripts/%{name}-linux-swt/target/%{name}-%{version}-linux-swt/dist/* %{buildroot}/%{_datadir}/%{name}

# desktop files
install -dm 755 %{buildroot}/%{_datadir}/applications
install -pm 644 desktop/build-scripts/common-resources/common-linux/share/applications/tuxguitar.desktop %{buildroot}/%{_datadir}/applications/

# icon
install -D -m 644 desktop/build-scripts/common-resources/common-linux/share/pixmaps/tuxguitar.png %{buildroot}%{_datadir}/pixmaps/tuxguitar.png
%suse_update_desktop_file -n -i tuxguitar AudioVideo Music Java

# man page
mkdir -p %{buildroot}/%{_mandir}/man1
cp -a desktop/build-scripts/common-resources/common-linux/share/man/man1/%{name}.1 %{buildroot}/%{_mandir}/man1/

%fdupes -s %{buildroot}

ln -sf %{_jnidir}/%{name}/%{name}-alsa.jar %{buildroot}%{_javadir}/%{name}/
ln -sf %{_jnidir}/%{name}/%{name}-jack.jar %{buildroot}%{_javadir}/%{name}/
%if 0%{?suse_version} >= 1500
ln -sf %{_jnidir}/%{name}/%{name}-fluidsynth.jar %{buildroot}%{_javadir}/%{name}/
%endif
%if 0%{?suse_version} > 1500
ln -sf %{_jnidir}/%{name}/%{name}-synth-lv2.jar %{buildroot}%{_javadir}/%{name}/
%endif

%files -f .mfiles
%license LICENSE
%doc AUTHORS CHANGES README.md
%{_libdir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/mime/packages/%{name}.xml
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_javadir}/%{name}/tuxguitar-alsa.jar
%{_javadir}/%{name}/tuxguitar-jack.jar
%if 0%{?suse_version} >= 1500
%{_javadir}/%{name}/tuxguitar-fluidsynth.jar
%endif
%if 0%{?suse_version} > 1500
%{_javadir}/%{name}/tuxguitar-synth-lv2.jar
%endif

%changelog
* Sat Dec 28 2024 guiv42 <guiv42@tuta.io>
- Updated to new upstream release 1.6.6
  * Add zoom control for Print/Export to pdf
  * Improve GP and tef v2 import
  * Save/restore player mode when switching tabs
  * Export only audible tracks to MIDI and audio files
  * Restore scrollbars during playback
  * Minor improvements, cleanups, bug fixes
* Sun Aug 25 2024 guiv42 <guiv42@tuta.io>
- Updated to new upstream release 1.6.4
  * Updated translations
  * Reworked duration and division menus
  * More small improvements and cleanups
- Removed patch:
  * 0013-desktop.patch
    + deleted, no more needed
* Thu Jun  6 2024 guiv42 <guiv42@tuta.io>
- Updated to new upstream release 1.6.3
- Remove achitecture-specific patches, no more needed:
  * 0001-tuxguitar-aarch64.patch
  * 0002-tuxguitar-armv6hl.patch
  * 0003-tuxguitar-armv7hl.patch
  * 0004-tuxguitar-ppc64.patch
  * 0005-tuxguitar-ppc64le.patch
  * 0006-tuxguitar-riscv64.patch
  * 0007-tuxguitar-s390x.patch
  * 0008-tuxguitar-x86.patch
- Updated patches, no more architecture-specific:
  * 0009-no-lv2.patch
  * 0010-no-fluidsynth.patch
* Thu Apr 11 2024 Fridrich Strba <fstrba@suse.com>
- Updated to new upstream release 1.6.2
  * Remove VST plugin (#312)
- Removed patch:
  * 0009-no-vst.patch
    + vst removed by upstream
- Modified patches:
  * 0001-tuxguitar-aarch64.patch
  * 0002-tuxguitar-armv6hl.patch
  * 0003-tuxguitar-armv7hl.patch
  * 0004-tuxguitar-ppc64.patch
  * 0005-tuxguitar-ppc64le.patch
  * 0006-tuxguitar-riscv64.patch
  * 0007-tuxguitar-s390x.patch
  * 0008-tuxguitar-x86.patch
  * 0010-no-lv2.patch -> 0009-no-lv2.patch
  * 0011-no-fluidsynth.patch -> 0010-no-fluidsynth.patch
  * 0012-default-soundfont.patch -> 0011-default-soundfont.patch
  * 0013-startscript.patch -> 0012-startscript.patch
  * 0014-desktop.patch -> 0013-desktop.patch
    + Rediff to changed context and adapt to removal of vst
* Thu Mar 14 2024 guiv42 <guiv42@tuta.io>
- Modified patch 0013-startscript.patch
  include commons-io following update of commons-compress package
  needed to open .gp files
* Wed Feb 21 2024 Gus Kenion <gus.kenion@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Feb  2 2024 guiv42 <guiv42@tuta.io>
- Updated to new upstream release 1.6.1
- Simplified architecture-specific patches
  * remove unused configurations: jfx, qt, debian
- removed tuxguitar-viewer, deprecated upstream
- deleted tuxguitar-CVE-2020-13940.patch, integrated upstream
* Fri Feb  2 2024 guiv42 <guiv42@tuta.io>
- Updated to new upstream release 1.6.1
- Simplified architecture-specific patches
  * remove unused configurations: jfx, qt, debian
- removed tuxguitar-viewer, deprecated upstream
- deleted tuxguitar-CVE-2020-13940.patch, integrated upstream
* Sat Oct 21 2023 guiv42 <guiv42@tuta.io>
- Added path to commons-compress in 0013-startscript.patch
  to enable TuxGuitar to open .gp files
* Thu Oct 12 2023 Fridrich Štrba <fstrba@suse.com>
- Added patch:
  * tuxguitar-CVE-2020-13940.patch
    + fix bsc#1173633 (CVE-2020-14940): improper configuration of
    XML parsers might lead to XXE while loading GP6 (.gpx) and
    GP7 (.gp) tablature files
* Thu Oct 12 2023 Fridrich Strba <fstrba@suse.com>
- Package also a sample tuxguitar.tg file
- Modified patch:
  * 0013-startscript.patch
    + compose the CLASSPATH jar by jar, since wildcards are not
    working for CLASSPATH variable
* Wed Oct 11 2023 Fridrich Strba <fstrba@suse.com>
- Allow building on all supported architectures and distributions
- Added patches:
  * 0001-tuxguitar-aarch64.patch
    + allow building native parts of tuxguitar for aarch64
  * 0002-tuxguitar-armv6hl.patch
    + allow building native parts of tuxguitar for armv6hl
  * 0003-tuxguitar-armv7hl.patch
    + allow building native parts of tuxguitar for armv7hl
  * 0004-tuxguitar-ppc64.patch
    + allow building native parts of tuxguitar for ppc64
  * 0005-tuxguitar-ppc64le.patch
    + allow building native parts of tuxguitar for pcc64le
  * 0006-tuxguitar-riscv64.patch
    + allow building native parts of tuxguitar for riscv64
  * 0007-tuxguitar-s390x.patch
    + allow building native parts of tuxguitar for s390x
  * 0008-tuxguitar-x86.patch
    + allow building native parts of tuxguitar for 32-bit intel
    platform
  * 0010-no-lv2.patch
    + disable lv2 synthesizer on platforms that lack the
    dependencies
  * 0011-no-fluidsynth.patch
    + disable fluidsynth synthesizer on platforms that lack the
    dependency
- Modified patches:
  * no-vst.patch -> 0009-no-vst.patch
    + extend to all ported architectures and manage with git to make
    rediffs easier for newer versions
  * desktop.patch -> 0014-desktop.patch
  * tuxguitar-default-soundfont.patch -> 0012-default-soundfont.patch
  * tuxguitar-startscript.patch -> 0013-startscript.patch
    + manage with git to make rediffs easier for newer versions
* Mon Oct  9 2023 guiv42 <guiv42@tuta.io>
- Add complementary information to previous changelog
- Deleted patches
  * tuxguitar-startscript-itext.patch
  * tuxguitar-additional-arch.patch
  * no-fluidsynth.patch
- Added new patch, required by release 1.6.0
  * desktop.patch
* Sat Oct  7 2023 guiv42 <guiv42@tuta.io>
- Update to new upstream release 1.6.0
  * switch to https://github.com/helge17/tuxguitar
    as source repo, since historical repo is orphaned
  * only x86_64 arch is supported by source repo
* Thu Oct 13 2022 Fridrich Strba <fstrba@suse.com>
- Force building with java 11 on ix86 in order to avoid random
  build failures
* Wed Mar 23 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Tue Feb  8 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * no-fluidsynth.patch
    + disable fluidsynth for building on sle12
* Sun Aug  1 2021 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * tuxguitar-additional-arch.patch
    + add armv6hl
* Wed Jul  8 2020 Fridrich Strba <fstrba@suse.com>
- Add viewer and tray to the built modules
* Wed Jul  8 2020 Fridrich Strba <fstrba@suse.com>
- Update to version 1.5.4
- Removed patches:
  * tuxguitar-do-not-force-java-1.5.patch
  * tuxguitar-jsa-build.patch
  * tuxguitar-tray-build.patch
    + not needed anymore, since we don't use the ant build system
- Modified patch.
  * tuxguitar-startscript.patch
    + adapt to work with openSUSE layout of directories
- Added patches:
  * tuxguitar-startscript-itext.patch
    + apply when building --with itext in order to have the
    necessary libraries in the classpath
  * no-vst.patch
    + do not build the parts that need unavailable VST SDK
  * tuxguitar-additional-arch.patch
    + extend supported architectures to aarch64, ppc64, ppc64le,
    and s390x
* Fri Oct  5 2018 opensuse.lietuviu.kalba@gmail.com
- Remove FluidSynth and fluid-soundfont-gm dependencies for
  openSUSE Leap 15 and newer versions.
* Sun Oct 22 2017 fstrba@suse.com
- Build with java and source target levels 1.6
  * Solves one of the issues raised in boo#1062807
* Fri Sep 22 2017 opensuse.lietuviu.kalba@gmail.com
- Add tuxguitar-do-not-force-java-1.5.patch: Don't force JAVA 1.5
* Fri Jun 23 2017 opensuse.lietuviu.kalba@gmail.com
- Rewrite spec file, based on spec file from Fedora Project.
- Updated to version 1.4 (bnc#1038205)
  * New edit Toolbar
  * Several bugs fixed
* Fri Dec 11 2015 opensuse.lietuviu.kalba@gmail.com
- Fix building for openSUSE Leap 42.1 by removing itext dependency.
  Itext used for printing to PDFs.
* Mon Nov 10 2014 Led <ledest@gmail.com>
- fix bashisms in post/postun scripts
* Tue Jun 26 2012 mvyskocil@suse.cz
- build require java-devel >= 1.6.0
* Sun Oct  2 2011 embar@users.berlios.de
- added itext to requires section
* Sun Sep 18 2011 embar@users.berlios.de
- don't strict to swt 3.4 version
* Tue Jun  8 2010 mseben@novell.com
- added libswt3-gtk2 to requires section (bnc#611710)
* Tue Dec  1 2009 mseben@novell.com
- added timidity to requires section (bnc#556711)
* Thu Nov  5 2009 mseben@novell.com
- updated to version 1.2
  * Support measure range to loop
  * Transpose notes feature
  * Optionally transpose afected notes when change tuning
  * Move beats left|right support
  * More song properties options.
  * Add multiple measure support
  * Clean multiple measure support
  * Number of pastes support
  * Better lilypond plugin
  * Better fluidsynth plugin
  * New jack plugin
  * New community integration plugin
  * New cocoa integration plugin
  * New audio unit plugin
  * Many bug fixes
* Tue Jun 16 2009 mseben@suse.cz
- initial openSUSE package for tuxguitar 1.1 (modified spec from tarball)
